## Convergence

Settings that control the convergence of the simulation run with cosmic-pop

### `convergence_params`

A list of parameters you would like to verify have converged to a single distribution shape when running cosmic-pop from the command line.

Default: [mass_1, mass_2, porb, ecc]

mass_1
mass_2
sep
porb
ecc
massc_1
massc_2
rad_1
rad_2
Option details

- `mass_1`: Primary mass
- `mass_2`: Secondary mass
- `sep`: Separation
- `porb`: Orbital period
- `ecc`: Eccentricity
- `massc_1`: Primary core mass
- `massc_2`: Secondary core mass
- `rad_1`: Primary radius
- `rad_2`: Secondary radius

### `convergence_limits`

Specifies limits for parameters included in the `convergence_params` list.

Default: {}

Option details

For each parameter specified `convergence_limits`, the lower and upper limit must be included.

- `{}`: No limits specified
- `{'mass_1' : [5, 10], 'sep' : [0, 10]}`: For example, this specifies that the primary mass must be between 5 and 10 solar masses, and the separation must be between 0 and 10 Rsun.

### `pop_select`

Selects the stage of the evolution at which you would like to check for convergence.

Default: formation

Option details

This will filter for systems that satisfy the `final_kstar1` and `final_kstar2` selections from the command line call of cosmic-pop at the following states:

- `formation`: At binary formation
- `1_SN`: Just before the first supernova
- `2_SN`: Just before the second supernova
- `disruption`: Just before binary disruption
- `final_state`: After the full evolution specified by the user-supplied evolution time
- `XRB_form`: At the start of RLOF following the first supernova

### `apply_convergence_limits`

Whether to filter the binary population (including the bcm, bpp, initC, and kick_info DataFrames) to only contain the binaries that satisfy the constraints from convergence_limits.

Default: False

Option details

- `True`: Filter the binary population to only contain the binaries that satisfy the constraints from convergence_limits
- `False`: Do not filter the binary population

### `match`

Provides the tolerance for the convergence calculation and is calculated as \({\rm match} = \log_{\rm 10} (1 - {\rm convergence})\)

Default: -5.0

Option details

- `-5.0`: For example, this specifies a tolerance of \(10^{-5}\) for convergence